{ config, pkgs, lib, ... }: let 
  cfg = config.internal.nas0; 
in {
  options = {
    internal.nas0 = {
      useSMB = lib.mkEnableOption "use SMB to connect to nas0";
      useNFS = lib.mkEnableOption "use NFS to connect to nas0";
      useiSCSI = lib.mkEnableOption "use iSCSI to connect to nas0";
        
      mountUid = lib.mkOption {
        type = lib.types.number;
        default = 1000;
        description = ''
          UID for the mount
        '';
      };

      mountGid = lib.mkOption {
        type = lib.types.number;
        default = 100;
        description = ''
          GID for the mount
        '';
      };
    };
  };

  config = lib.mkIf cfg.useSMB {
    sops.secrets.smb_credentials = {
      sopsFile = ../../secrets/default.yaml;
    };

    fileSystems."/mnt/nas0" = {
      device = "//nas0.hoki-porgy.ts.net/main/";
      fsType = "cifs";
      options = let
        automount_opts = "x-systemd.automount,noauto,x-systemd.idle-timeout=60,x-systemd.device-timeout=5s,x-systemd.mount-timeout=5s";
      in [
        "${automount_opts},X-mount.mkdir,credentials=${config.sops.secrets.smb_credentials.path},uid=${toString cfg.mountUid},gid=${toString cfg.mountGid}"
      ];
    };

    environment.systemPackages = [
      pkgs.cifs-utils
      pkgs.samba
    ];
  } // lib.mkIf cfg.useNFS {
    fileSystems."/mnt/nas0" = {
      device = "nas0.hoki-porgy.ts.net:/storage";
      fsType = "nfs";
      options = [ 
        "x-systemd.automount,noauto,x-systemd.idle-timeout=60,x-systemd.device-timeout=5s,x-systemd.mount-timeout=5s" 
        "X-mount.mkdir,uid=${toString cfg.mountUid},gid=${toString cfg.mountGid}"
      ];
    } // lib.mkIf cfg.useiSCSI {

    };
  };
}
